from shutil import copyfile
from pathlib import Path

from w3nest.ci.ts_frontend import ProjectConfig, PackageType, Dependencies, \
    RunTimeDeps, generate_template, AuxiliaryModule, Bundles, MainModule
from w3nest.utils import parse_json

project_folder = Path(__file__).parent.parent

pkg_json = parse_json(project_folder / 'package.json')

load_dependencies = {
    "rx-vdom": "^0.1.0",
    "rxjs": "^7.5.6",
    "@w3nest/webpm-client": "^0.1.0",
    "codemirror": "^5.52.0",
}

config = ProjectConfig(
    path=project_folder,
    type=PackageType.LIBRARY,
    name=pkg_json['name'],
    version=pkg_json['version'],
    shortDescription=pkg_json['description'],
    author=pkg_json['author'],
    dependencies=Dependencies(
        runTime=RunTimeDeps(
            externals={
                **load_dependencies,
                "typescript": "5.6.3",
                "@typescript/vfs": "^1.4.0"
            }
        ),
        devTime={
            "@types/codemirror": "^5.52.0",  # Required to generate doc
            "lz-string": "^1.4.4",  # Required to generate doc
        }
    ),
    bundles=Bundles(
        mainModule=MainModule(
            entryFile="./lib/index.ts",
            loadDependencies=list(load_dependencies.keys())
        ),
        auxiliaryModules=[
            AuxiliaryModule(
                name='typescript-addon',
                entryFile="./lib/typescript/index.ts",
                loadDependencies=["typescript", "@typescript/vfs"]
            )
        ],
    ),
)

template_folder = project_folder / '.w3nest'  / '.template'
generate_template(config=config, dst_folder=template_folder)


files = [
    Path("src") / "auto-generated.ts",
    "README.md",
    '.gitignore',
    '.npmignore',
    '.prettierignore',
    "package.json",
    "tsconfig.json",
    "jest.config.ts",
    "webpack.config.ts",
    ]
for file in files:
    copyfile(src=template_folder / file, dst=project_folder / file)


